@@ -120,7 +120,18 @@ func (c *OwnedCluster) Delete(ctx context.Context, _, podEvictionWaitPeriod time
 	}
 	newTasksToDeleteAddonIAM := addon.NewRemover(c.stackManager).DeleteAddonIAMTasks
 	newTasksToDeletePodIdentityRoles := func() (*tasks.TaskTree, error) {
-		return podidentityassociation.NewDeleter(c.cfg.Metadata.Name, c.stackManager, c.ctl.AWSProvider.EKS()).
+		if !clusterOperable {
+			return &tasks.TaskTree{}, nil
+		}
+		clientSet, err = c.newClientSet()
+		if err != nil {
+			if force {
+				logger.Warning("error occurred while deleting IAM Role stacks for pod identity associations: %v; force=true so proceeding with cluster deletion", err)
+				return &tasks.TaskTree{}, nil
+			}
+			return nil, err
+		}
+		return podidentityassociation.NewDeleter(c.cfg.Metadata.Name, c.stackManager, c.ctl.AWSProvider.EKS(), clientSet).
 			DeleteTasks(ctx, []podidentityassociation.Identifier{})
 	}
 
