@@ -12,7 +12,10 @@ echo "eksctl: running /etc/eks/bootstrap"
   --b64-cluster-ca "${B64_CLUSTER_CA}" \
   --dns-cluster-ip "${CLUSTER_DNS}" \
   --kubelet-extra-args "${KUBELET_EXTRA_ARGS}" \
-  --container-runtime "${CONTAINER_RUNTIME}"
+  --container-runtime "${CONTAINER_RUNTIME}" \
+  ${ENABLE_LOCAL_OUTPOST:+--enable-local-outpost "${ENABLE_LOCAL_OUTPOST}"} \
+  ${CLUSTER_ID:+--cluster-id "${CLUSTER_ID}"}
+
 
 echo "eksctl: merging user options into kubelet-config.json"
 trap 'rm -f ${TMP_KUBE_CONF}' EXIT
